# trad-setlist-helper

Use data from The Session to generate incipts for a list of tune sets.

[PyScript](https://pyscript.net) app (WIP):
[dev](https://raw.githack.com/zmoon/trad-setlist-helper/main/app/)

Examples to try:

```
reel: Cooley's
reels: Cooley's / The Wise Maid [118] / The Maid Behind The Bar
jigs: The Banks of Loch Gowna / Winnie Hayes / The Mouse in the Kitchen
```

---

Would be nice to add:

- [ ] fuzzy name matching
- [ ] fuzzy key/mode matching (e.g. same key sig, maybe even min and dor matching)
- [ ] default to Norbeck or such for the transcription if available
